#pragma once
#include <string>
#include <vector>
#include <filesystem>
#include <fstream>
#include <stdexcept>
#include <algorithm>

class TreeStructurer {
public:
    TreeStructurer() = default;
    
    std::vector<std::string> get_directory_structure(const std::string& startpath = std::filesystem::current_path().string());
    void create_structure_from_file(const std::string& filepath, const std::string& target_path = std::filesystem::current_path().string());

private:
    struct TreeNode {
        std::string name;
        bool is_file;
        std::vector<TreeNode> children;
    };

    bool should_ignore_dir(const std::string& dirname);
    bool should_ignore_file(const std::string& filename);
    std::string create_indent(size_t level);
    std::string get_relative_path(const std::filesystem::path& path, const std::filesystem::path& base);
    std::vector<std::filesystem::path> get_filtered_paths(const std::filesystem::path& start);
    size_t get_indent_level(const std::string& line);
    TreeNode parse_structure_line(const std::string& line, size_t indent_level);
    TreeNode build_tree_from_lines(const std::vector<std::string>& lines);
    void create_node(const TreeNode& node, const std::filesystem::path& current_path);
    bool is_directory_marker(const std::string& line);
    void create_directory(const std::filesystem::path& path);
    void create_file(const std::filesystem::path& path);
    std::vector<std::string> read_structure_file(const std::string& filepath);
    void validate_structure(const std::vector<std::string>& lines);
    std::string sanitize_path(const std::string& path);

    // Update the constants to use wide characters
    static const wchar_t DIRECTORY_MARKER = L'/';
    static const wchar_t TREE_PIPE = L'│';
    static const wchar_t TREE_BRANCH = L'├';
    static const wchar_t TREE_CORNER = L'└';
    static const wchar_t TREE_DASH = L'─';
};
